% ISINTTYPE ISINTTYPE Test For Integer-type Array
% 
% Usage
% 
% The syntax for isinttype is 
% 
%    x = isinttype(y)
% 
% and it returns a logical 1 if the argument is an integer type
% and a logical 0 otherwise.  Note that this function only tests
% the type of the variable, not the value.  So if, for example,
% y is a float array containing all integer values, it will
% still return a logical 0.
function x = isinttype(y)
  x = isinteger(y);
